// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.name.container;

import java.util.ArrayList;
import java.util.List;

import eu.etaxonomy.cdm.model.name.HomotypicalGroup;
import eu.etaxonomy.cdm.model.taxon.Synonym;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.editor.name.TaxonNameEditor;

/**
 * @author n.hoffmann
 * @created Jan 21, 2011
 * @version 1.0
 */
public abstract class AbstractHomotypicalGroupContainer extends AbstractGroup {

	private HomotypicalGroup group;
	
	/**
	 * @param editor
	 */
	public AbstractHomotypicalGroupContainer(TaxonNameEditor editor, HomotypicalGroup group) {
		super(editor);
		this.group = group;

		createContent();
	}

	protected abstract void createSynonymContainer();
	
	protected List<Synonym> getSynonyms(){
		Taxon taxon = getEditor().getTaxon();
		return taxon.getSynonymsInGroup(getGroup());
	}
	
	/**
	 * @param group the group to set
	 */
	public void setGroup(HomotypicalGroup group) {
		this.group = group;
	}

	public void redraw(HomotypicalGroup homotypicalGroup){
		if(redrawNeeded(homotypicalGroup)){
			setGroup(homotypicalGroup);
			redraw();
		}
	}

	/**
	 * 
	 * @param homotypicalGroup
	 * @return
	 */
	protected boolean redrawNeeded(HomotypicalGroup homotypicalGroup) {
		Taxon taxon = getEditor().getTaxon();
		List<Synonym> synonyms = taxon.getSynonymsInGroup(homotypicalGroup);
		
		List<Synonym> presentSynonyms = new ArrayList<Synonym>();
		
		for(AbstractGroupedContainer container : getGroupedContainers()){
			if(container.getData() instanceof Synonym){
				presentSynonyms.add((Synonym) container.getData());
			}
		}
				
		boolean result = ! (presentSynonyms.containsAll(synonyms) && synonyms.containsAll(presentSynonyms));
		
		return result;
	}
	
	/**
	 * @return the group
	 */
	public HomotypicalGroup getGroup() {
		return group;
	}
}
