// $Id$
/**
* Copyright (C) 2013 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.editor.view.dataimport;

import java.net.MalformedURLException;
import java.net.URI;
import java.net.URISyntaxException;
import java.net.URL;

import org.eclipse.jface.wizard.WizardPage;
import org.eclipse.swt.widgets.Composite;

import eu.etaxonomy.taxeditor.view.specimenSearch.SpecimenProviderSelectionController;


/**
 * Wizard page for selecting the specimen provider
 * @author pplitzner
 * @date 12.09.2013
 *
 */
public class SpecimenProviderSelectionWizardPage extends WizardPage{

    private SpecimenProviderSelectionController specimenProviderSelectionController;
    private URI endPoint;

    protected SpecimenProviderSelectionWizardPage(String pageName) {
        super(pageName);
        setTitle("Select Specimen Provider");
        setDescription("Select the provider to query for specimens.\nTo query a BioCASE " +
        		"provider the access point URL must be entered.");
    }

    /* (non-Javadoc)
     * @see org.eclipse.jface.dialogs.IDialogPage#createControl(org.eclipse.swt.widgets.Composite)
     */
    @Override
    public void createControl(Composite parent) {
        specimenProviderSelectionController = SpecimenProviderSelectionController.getInstance(parent, getWizard());
        setControl(specimenProviderSelectionController.getComposite());
    }

    public QueryType getQueryType(){
        if(specimenProviderSelectionController.getComposite().getBtnBioCaseProvider().getSelection()){
            return QueryType.BIOCASE;
        }
        else {// if(specimenProviderSelectionController.getComposite().getBtnGbif().getSelection()){
            return QueryType.GBIF;
        }
    }

    /**
     * @return
     * @throws URISyntaxException
     */
    public URI getEndPoint() {
        return endPoint;
    }

    /* (non-Javadoc)
     * @see org.eclipse.jface.wizard.WizardPage#isPageComplete()
     */
    @Override
    public boolean isPageComplete() {
        if(specimenProviderSelectionController.getComposite().getBtnBioCaseProvider().getSelection()){
            endPoint = null;
            try {
                endPoint = new URL(specimenProviderSelectionController.getComposite().getTxtAccessPoint().getText()).toURI();
                this.setErrorMessage(null);
                return true;
            } catch (MalformedURLException e) {
                setErrorMessage("A valid URL has to be entered.");
                return false;
            } catch (URISyntaxException e) {
                setErrorMessage("A valid URL has to be entered.");
                return false;
            }
        }
        else if(specimenProviderSelectionController.getComposite().getBtnGbif().getSelection()){
            this.setErrorMessage(null);
            return true;
        }
        return false;
    }

    /**
     * @return
     */
    public SpecimenProviderSelectionController getController() {
        return specimenProviderSelectionController;
    }


}
