// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy
* http://www.e-taxonomy.eu
*
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.view.media;

import org.eclipse.jface.action.GroupMarker;
import org.eclipse.jface.action.MenuManager;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.jface.viewers.Viewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Menu;
import org.eclipse.swt.widgets.Tree;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.IWorkbenchActionConstants;
import org.eclipse.ui.IWorkbenchPart;

import eu.etaxonomy.taxeditor.bulkeditor.BulkEditor;
import eu.etaxonomy.taxeditor.editor.MultiPageTaxonEditor;
import eu.etaxonomy.taxeditor.model.AbstractUtility;
import eu.etaxonomy.taxeditor.model.IPartContentHasDetails;
import eu.etaxonomy.taxeditor.model.IPartContentHasSupplementalData;
import eu.etaxonomy.taxeditor.view.AbstractCdmEditorViewPart;

/**
 * <p>MediaViewPart class.</p>
 *
 * @author n.hoffmann
 * @created Jun 15, 2010
 * @version 1.0
 */
public class MediaViewPart extends AbstractCdmEditorViewPart implements IPartContentHasDetails, IPartContentHasSupplementalData {

	/** Constant <code>ID="eu.etaxonomy.taxeditor.editor.view.medi"{trunked}</code> */
	public static final String ID = "eu.etaxonomy.taxeditor.editor.view.media";

	private TreeViewer viewer;

	/*
	 * (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.model.AbstractCdmViewPart#createViewer(org.eclipse.swt.widgets.Composite)
	 */
	/** {@inheritDoc} */
	@Override
	public void createViewer(Composite parent) {

		viewer = new TreeViewer(new Tree(parent, SWT.MULTI | SWT.H_SCROLL
				| SWT.V_SCROLL | SWT.FULL_SELECTION));

		viewer.setContentProvider(new MediaContentProvider());
		viewer.setLabelProvider(new MediaLabelProvider());
		viewer.setAutoExpandLevel(2);

		// Propagate selection from viewer
		getSite().setSelectionProvider(viewer);

		// Add context menu to tree
		MenuManager menuMgr = new MenuManager();
		menuMgr.add(new GroupMarker(IWorkbenchActionConstants.MB_ADDITIONS));
		getSite().registerContextMenu(menuMgr, viewer);

		Control control = viewer.getControl();
		Menu menu = menuMgr.createContextMenu(control);
		control.setMenu(menu);

	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.model.AbstractCdmViewPart#getInitialSelection()
	 */
	/** {@inheritDoc} */
	@Override
	protected ISelection getInitialSelection() {
		if(getEditor() != null){
			return new StructuredSelection(getEditor().getEditorInput());
		}

		return super.getInitialSelection();
	}

	/** {@inheritDoc} */
	@Override
    protected void internal_selectionChanged(IWorkbenchPart part, ISelection selection) {
		if(AbstractUtility.getActiveEditor() == null){
			showEmptyPage();
			return;
		}

		if(part instanceof MultiPageTaxonEditor){
			IEditorInput input = ((IEditorPart) part).getEditorInput();
			showViewer(part, new StructuredSelection(input));
		}

		if(part instanceof BulkEditor && selection instanceof IStructuredSelection){
			showViewer(part, (IStructuredSelection) selection);
		}
	}

	/** {@inheritDoc} */
	@Override
	public void changed(Object object) {
		viewer.refresh();
		super.changed(object);
	}

	/** {@inheritDoc} */
	@Override
	public Viewer getViewer() {
		return viewer;
	}

	/**
	 * <p>onComplete</p>
	 *
	 * @return a boolean.
	 */
	@Override
    public boolean onComplete() {
		return true;
	}
}
